pub fn checkpoint_truncate(conn: &Connection) -> Result<(), DbError>Expand description
Safely flushes all committed transactions from the WAL file into the main database file and truncates the WAL to zero bytes. Returns an error if the database is busy and unable to truncate.