Module ops

Module ops 

Enums

OpError

Functions

blast_radius_op
Compute blast radius and likely tests for a symbol, file, or uncommitted git changes.
codebase_outline_op
Generate a memory-bounded codebase outline pushed down into SQLite.
file_skeleton_op
Generate file skeleton with fresh file synchronization.
get_context_slice_op
Retrieve a complete context slice for a symbol, guaranteeing fresh offsets.
get_symbol_body_op
Retrieve the body of a symbol by name, guaranteeing fresh offsets and file contents.