pub fn count_parse_diagnostics(conn: &Connection, path: &str) -> usizeExpand description
Count parse diagnostics recorded for a file, returning 0 when the index has none.
pub fn count_parse_diagnostics(conn: &Connection, path: &str) -> usizeCount parse diagnostics recorded for a file, returning 0 when the index has none.