pub fn count_unsupported_files(
conn: &Connection,
path_filter: Option<&str>,
) -> usizeExpand description
Count files julie could not parse under a path, returning 0 when the index has none.
pub fn count_unsupported_files(
conn: &Connection,
path_filter: Option<&str>,
) -> usizeCount files julie could not parse under a path, returning 0 when the index has none.