pub fn file_not_found_parts(
conn: &Connection,
rel_path: &str,
) -> (String, String)Expand description
The workspace name and the recovery hint for a file that is not indexed.
pub fn file_not_found_parts(
conn: &Connection,
rel_path: &str,
) -> (String, String)The workspace name and the recovery hint for a file that is not indexed.