pub fn load_scoped_files(
conn: &Connection,
path_filter: Option<&str>,
) -> Result<Vec<FileFact>, QueryError>Expand description
Retrieve indexed files optionally scoped by path filter, pushed down to SQLite.
pub fn load_scoped_files(
conn: &Connection,
path_filter: Option<&str>,
) -> Result<Vec<FileFact>, QueryError>Retrieve indexed files optionally scoped by path filter, pushed down to SQLite.