pub fn suggest_file_paths(conn: &Connection, rel_path: &str) -> Vec<String>Expand description
Up to three indexed file paths close to rel_path. Never fails.
pub fn suggest_file_paths(conn: &Connection, rel_path: &str) -> Vec<String>Up to three indexed file paths close to rel_path. Never fails.