create_index

Function create_index 

pub fn create_index(
    workspace: &Workspace,
    db_path: &Path,
) -> Result<(), SyncError>
Cold-start background sweep: checks filesystem against SQLite files records. Streams disk checks and uses an in-memory SQLite index to eliminate repository-wide heap HashMaps. Creates a missing index. A git worktree copies its parent repository’s index and reconciles it against the worktree files, which is much faster than a full scan; anything else runs a full scan.