ensure_fresh_file

Function ensure_fresh_file 

pub fn ensure_fresh_file(
    workspace: &Workspace,
    db_path: &Path,
    conn: &Connection,
    rel_path: &str,
) -> Result<bool, SyncError>
Tier 2: Just-In-Time Staleness Guard Checks if a file on disk has been modified since it was indexed in SQLite. If dirty or missing from index, re-extracts the file synchronously (< 5ms).