pub fn record_tool_call(workspace_root: &Path, invocation: &ToolInvocation<'_>)Expand description
Record a tool call to the global telemetry database. Best-effort and non-panicking.
pub fn record_tool_call(workspace_root: &Path, invocation: &ToolInvocation<'_>)Record a tool call to the global telemetry database. Best-effort and non-panicking.