pub fn start_watcher(
workspace: Workspace,
db_path: PathBuf,
) -> Result<WatcherHandle, WatcherError>Expand description
Starts debounced background file watcher with git storm circuit breaker.
pub fn start_watcher(
workspace: Workspace,
db_path: PathBuf,
) -> Result<WatcherHandle, WatcherError>Starts debounced background file watcher with git storm circuit breaker.