local_variable_predicate

Function local_variable_predicate 

pub fn local_variable_predicate(alias: &str) -> String
SQL predicate that is true for a symbols row that is a local variable or a parameter: a variable declared inside a function, method, or constructor, directly or through enclosing variables such as closures.