Module ops

Module ops 

Enums

OpError
SymbolSelector

Constants

MAX_CONTEXT_OVERLOADS
A context read builds callees, types, and tests for each overload, so it stops at this many.

Functions

blast_radius_op
Compute blast radius and likely tests for a symbol, file, or uncommitted git changes.
blast_radius_selected_op
codebase_outline_op
Generate a memory-bounded codebase outline pushed down into SQLite.
file_skeleton_op
Generate file skeleton with fresh file synchronization.
get_context_slice_op
Retrieve a complete context slice for a symbol, guaranteeing fresh offsets.
get_context_slice_selected_op
get_context_slices_selected_op
Like get_context_slice_selected_op, but a name that selects up to MAX_CONTEXT_OVERLOADS overloads of one owner in one file returns a slice for each overload.
get_symbol_bodies_selected_op
Like get_symbol_body_selected_op, but a name that selects several overloads of one owner in one file returns the body of each overload instead of an ambiguity error.
get_symbol_body_op
Retrieve the body of a symbol by name, guaranteeing fresh offsets and file contents.
get_symbol_body_selected_op
resolve_symbol_op