Enums
Constants
- MAX_
CONTEXT_ OVERLOADS - A context read builds callees, types, and tests for each overload, so it stops at this many.
Functions
- blast_
radius_ op - Compute blast radius and likely tests for a symbol, file, or uncommitted git changes.
- blast_
radius_ selected_ op - codebase_
outline_ op - Generate a memory-bounded codebase outline pushed down into SQLite.
- file_
skeleton_ op - Generate file skeleton with fresh file synchronization.
- get_
context_ slice_ op - Retrieve a complete context slice for a symbol, guaranteeing fresh offsets.
- get_
context_ slice_ selected_ op - get_
context_ slices_ selected_ op - Like
get_context_slice_selected_op, but a name that selects up toMAX_CONTEXT_OVERLOADSoverloads of one owner in one file returns a slice for each overload. - get_
symbol_ bodies_ selected_ op - Like
get_symbol_body_selected_op, but a name that selects several overloads of one owner in one file returns the body of each overload instead of an ambiguity error. - get_
symbol_ body_ op - Retrieve the body of a symbol by name, guaranteeing fresh offsets and file contents.
- get_
symbol_ body_ selected_ op - resolve_
symbol_ op