Enums
Functions
- blast_
radius_ op - Compute blast radius and likely tests for a symbol, file, or uncommitted git changes.
- codebase_
outline_ op - Generate a memory-bounded codebase outline pushed down into SQLite.
- file_
skeleton_ op - Generate file skeleton with fresh file synchronization.
- get_
context_ slice_ op - Retrieve a complete context slice for a symbol, guaranteeing fresh offsets.
- get_
symbol_ body_ op - Retrieve the body of a symbol by name, guaranteeing fresh offsets and file contents.