Module telemetry

Module telemetry 

Structs

BugReportBundle
TelemetryErrorRecord
TelemetryFilter
TelemetrySummary
ToolInvocation
ToolStat

Enums

TimeWindow

Functions

format_telemetry_summary
generate_bug_report
get_global_telemetry_dir
get_telemetry_summary
is_telemetry_disabled
is_telemetry_disabled_with
open_global_telemetry_db
open_telemetry_db
Open the global telemetry database, delegating to open_global_telemetry_db().
open_telemetry_db_at
record_tool_call
Record a tool call to the global telemetry database. Best-effort and non-panicking.
record_tool_call_conn
Fast record of a tool invocation with normalized workspace path attribution.
resolve_telemetry_dir