Structs
Enums
Functions
- format_
telemetry_ summary - generate_
bug_ report - get_
global_ telemetry_ dir - get_
telemetry_ summary - is_
telemetry_ disabled - is_
telemetry_ disabled_ with - open_
global_ telemetry_ db - open_
telemetry_ db - Open the global telemetry database, delegating to
open_global_telemetry_db(). - open_
telemetry_ db_ at - record_
tool_ call - Record a tool call to the global telemetry database. Best-effort and non-panicking.
- record_
tool_ call_ conn - Fast record of a tool invocation with normalized workspace path attribution.
- resolve_
telemetry_ dir